# -*- coding: utf8 -*-
# ============LICENSE_START====================================================
# org.onap.vvp/validation-scripts
# ===================================================================
# Copyright © 2017 AT&T Intellectual Property. All rights reserved.
# ===================================================================
#
# Unless otherwise specified, all software contained herein is licensed
# under the Apache License, Version 2.0 (the "License");
# you may not use this software except in compliance with the License.
# You may obtain a copy of the License at
#
#             http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
#
#
# Unless otherwise specified, all documentation contained herein is licensed
# under the Creative Commons License, Attribution 4.0 Intl. (the "License");
# you may not use this documentation except in compliance with the License.
# You may obtain a copy of the License at
#
#             https://creativecommons.org/licenses/by/4.0/
#
# Unless required by applicable law or agreed to in writing, documentation
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# ============LICENSE_END============================================
#
#
from .helpers import validates

"""test_env_and_yaml_same_name
"""
from os import listdir
from os import path

VERSION = "1.0.0"


@validates("R-38474", "R-81725", "R-53433")
def test_env_and_yaml_same_name(template_dir):
    """
    Check that all environment template filenames are identical to an
    associated Heat template filenames. Log the result of the check and add the
    filename of any environment file that is badly named.
    """
    files = listdir(template_dir)
    env_files = [f for f in files if path.splitext(f)[-1] == ".env"]
    yaml_files = [f for f in files if path.splitext(f)[-1] in [".yml", ".yaml"]]
    unmatched = []
    for filename in env_files:
        basename = path.splitext(filename)[0]
        if basename + ".yaml" not in yaml_files and basename + ".yml" not in yaml_files:
            unmatched.append(filename)
    assert not unmatched, "files with no corresponding .y[a]ml %s" % unmatched
